@@ -9,7 +9,7 @@
  *  - adding tables
  *  - viewing PDF schemas
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -23,7 +23,7 @@ require_once "./libraries/blobstreaming.lib.php";
 
 // add a javascript file for jQuery functions to handle Ajax actions
 // also add jQueryUI
-$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.16.custom.js';
 $GLOBALS['js_include'][] = 'db_operations.js';
 
 /**
@@ -37,17 +37,18 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
         $move = false;
     }
 
-    if (!isset($newname) || !strlen($newname)) {
+    if (! isset($newname) || ! strlen($newname)) {
         $message = PMA_Message::error(__('The database name is empty!'));
     } else {
         $sql_query = ''; // in case target db exists
         $_error = false;
-        if ($move ||
-         (isset($create_database_before_copying) && $create_database_before_copying)) {
+        if ($move || (isset($create_database_before_copying) && $create_database_before_copying)) {
             // lower_case_table_names=1 `DB` becomes `db`
-            $lower_case_table_names = PMA_DBI_fetch_value('SHOW VARIABLES LIKE "lower_case_table_names"', 0, 1);
-            if ($lower_case_table_names === '1') {
-                $newname = strtolower($newname);
+            if (!PMA_DRIZZLE) {
+                $lower_case_table_names = PMA_DBI_fetch_value('SHOW VARIABLES LIKE "lower_case_table_names"', 0, 1);
+                if ($lower_case_table_names === '1') {
+                    $newname = PMA_strtolower($newname);
+                }
             }
 
             $local_query = 'CREATE DATABASE ' . PMA_backquote($newname);
@@ -69,37 +70,36 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
             $GLOBALS['pma']->databases->build();
         }
 
-        if (PMA_MYSQL_INT_VERSION >= 50000) {
-            // here I don't use DELIMITER because it's not part of the
-            // language; I have to send each statement one by one
+        // here I don't use DELIMITER because it's not part of the
+        // language; I have to send each statement one by one
 
-            // to avoid selecting alternatively the current and new db
-            // we would need to modify the CREATE definitions to qualify
-            // the db name
-            $procedure_names = PMA_DBI_get_procedures_or_functions($db, 'PROCEDURE');
-            if ($procedure_names) {
-                foreach($procedure_names as $procedure_name) {
-                    PMA_DBI_select_db($db);
-                    $tmp_query = PMA_DBI_get_definition($db, 'PROCEDURE', $procedure_name);
-                    // collect for later display
-                    $GLOBALS['sql_query'] .= "\n" . $tmp_query;
-                    PMA_DBI_select_db($newname);
-                    PMA_DBI_query($tmp_query);
-                }
-            }
-
-            $function_names = PMA_DBI_get_procedures_or_functions($db, 'FUNCTION');
-            if ($function_names) {
-                foreach($function_names as $function_name) {
-                    PMA_DBI_select_db($db);
-                    $tmp_query = PMA_DBI_get_definition($db, 'FUNCTION', $function_name);
-                    // collect for later display
-                    $GLOBALS['sql_query'] .= "\n" . $tmp_query;
-                    PMA_DBI_select_db($newname);
-                    PMA_DBI_query($tmp_query);
-                }
+        // to avoid selecting alternatively the current and new db
+        // we would need to modify the CREATE definitions to qualify
+        // the db name
+        $procedure_names = PMA_DBI_get_procedures_or_functions($db, 'PROCEDURE');
+        if ($procedure_names) {
+            foreach ($procedure_names as $procedure_name) {
+                PMA_DBI_select_db($db);
+                $tmp_query = PMA_DBI_get_definition($db, 'PROCEDURE', $procedure_name);
+                // collect for later display
+                $GLOBALS['sql_query'] .= "\n" . $tmp_query;
+                PMA_DBI_select_db($newname);
+                PMA_DBI_query($tmp_query);
             }
         }
+
+        $function_names = PMA_DBI_get_procedures_or_functions($db, 'FUNCTION');
+        if ($function_names) {
+            foreach ($function_names as $function_name) {
+                PMA_DBI_select_db($db);
+                $tmp_query = PMA_DBI_get_definition($db, 'FUNCTION', $function_name);
+                // collect for later display
+                $GLOBALS['sql_query'] .= "\n" . $tmp_query;
+                PMA_DBI_select_db($newname);
+                PMA_DBI_query($tmp_query);
+            }
+        }
+
         // go back to current db, just in case
         PMA_DBI_select_db($db);
 
@@ -109,7 +109,7 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
         $views = array();
 
         // remove all foreign key constraints, otherwise we can get errors
-        require_once './libraries/export/sql.php';
+        include_once './libraries/export/sql.php';
         foreach ($tables_full as $each_table => $tmp) {
             $sql_constraints = '';
             $sql_drop_foreign_keys = '';
@@ -124,7 +124,6 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
         }
         unset($sql_constraints, $sql_drop_foreign_keys, $sql_structure);
 
-
         foreach ($tables_full as $each_table => $tmp) {
             // to be able to rename a db containing views,
             // first all the views are collected and a stand-in is created
@@ -133,11 +132,17 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
                 $views[] = $each_table;
                 // Create stand-in definition to resolve view dependencies
                 $sql_view_standin = PMA_getTableDefStandIn($db, $each_table, "\n");
+                PMA_DBI_select_db($newname);
                 PMA_DBI_query($sql_view_standin);
-                $GLOBALS['sql_query'] .= "\n" . $sql_view_standin . ';';
+                $GLOBALS['sql_query'] .= "\n" . $sql_view_standin;
+            }
+        }
+
+        foreach ($tables_full as $each_table => $tmp) {
+            // skip the views; we have creted stand-in definitions
+            if (PMA_Table::isView($db, $each_table)) {
                 continue;
             }
-
             $back = $sql_query;
             $sql_query = '';
 
@@ -161,9 +166,10 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
                 //  for importing via the mysql client or our Import feature)
                 $triggers = PMA_DBI_get_triggers($db, $each_table, '');
 
-                if (! PMA_Table::moveCopy($db, $each_table, $newname, $each_table,
-                    isset($this_what) ? $this_what : 'data', $move, 'db_copy'))
-                {
+                if (! PMA_Table::moveCopy(
+                    $db, $each_table, $newname, $each_table,
+                    isset($this_what) ? $this_what : 'data', $move, 'db_copy')
+                ) {
                     $_error = true;
                     // $sql_query is filled by PMA_Table::moveCopy()
                     $sql_query = $back . $sql_query;
@@ -174,6 +180,7 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
                     PMA_DBI_select_db($newname);
                     foreach ($triggers as $trigger) {
                         PMA_DBI_query($trigger['create']);
+                        $GLOBALS['sql_query'] .= "\n" . $trigger['create'] . ';';
                     }
                     unset($trigger);
                 }
@@ -226,16 +233,16 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
             unset($GLOBALS['sql_constraints_query_full_db'], $one_query);
         }
 
-        if (PMA_MYSQL_INT_VERSION >= 50100) {
+        if (!PMA_DRIZZLE && PMA_MYSQL_INT_VERSION >= 50100) {
             // here DELIMITER is not used because it's not part of the
             // language; each statement is sent one by one
 
             // to avoid selecting alternatively the current and new db
             // we would need to modify the CREATE definitions to qualify
             // the db name
-            $event_names = PMA_DBI_fetch_result('SELECT EVENT_NAME FROM information_schema.EVENTS WHERE EVENT_SCHEMA= \'' . PMA_sqlAddslashes($db,true) . '\';');
+            $event_names = PMA_DBI_fetch_result('SELECT EVENT_NAME FROM information_schema.EVENTS WHERE EVENT_SCHEMA= \'' . PMA_sqlAddSlashes($db, true) . '\';');
             if ($event_names) {
-                foreach($event_names as $event_name) {
+                foreach ($event_names as $event_name) {
                     PMA_DBI_select_db($db);
                     $tmp_query = PMA_DBI_get_definition($db, 'EVENT', $event_name);
                     // collect for later display
@@ -244,9 +251,10 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
                     PMA_DBI_query($tmp_query);
                 }
             }
-    }
-    // go back to current db, just in case
-    PMA_DBI_select_db($db);
+        }
+
+        // go back to current db, just in case
+        PMA_DBI_select_db($db);
 
         // Duplicate the bookmarks for this db (done once for each db)
         if (! $_error && $db != $newname) {
@@ -261,7 +269,7 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
             /**
              * cleanup pmadb stuff for this db
              */
-            require_once './libraries/relation_cleanup.lib.php';
+            include_once './libraries/relation_cleanup.lib.php';
             PMA_relationsCleanupDatabase($db);
 
             // if someday the RENAME DATABASE reappears, do not DROP
@@ -272,7 +280,7 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
             $message = PMA_Message::success(__('Database %s has been renamed to %s'));
             $message->addParam($db);
             $message->addParam($newname);
-        } elseif (! $_error)  {
+        } elseif (! $_error) {
             $message = PMA_Message::success(__('Database %s has been copied to %s'));
             $message->addParam($db);
             $message->addParam($newname);
@@ -300,9 +308,9 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
      * Database has been successfully renamed/moved.  If in an Ajax request,
      * generate the output with {@link PMA_ajaxResponse} and exit
      */
-    if( $GLOBALS['is_ajax_request'] == true) {
+    if ( $GLOBALS['is_ajax_request'] == true) {
         $extra_data['newname'] = $newname;
-        $extra_data['sql_query'] = PMA_showMessage(NULL, $sql_query);
+        $extra_data['sql_query'] = PMA_showMessage(null, $sql_query);
         PMA_ajaxResponse($message, $message->isSuccess(), $extra_data);
     };
 }
@@ -327,12 +335,12 @@ if (isset($_REQUEST['comment'])) {
  * because there is no table in the database ($is_info is true)
  */
 if (empty($is_info)) {
-    require './libraries/db_common.inc.php';
+    include './libraries/db_common.inc.php';
     $url_query .= '&amp;goto=db_operations.php';
 
     // Gets the database structure
     $sub_part = '_structure';
-    require './libraries/db_info.inc.php';
+    include './libraries/db_info.inc.php';
     echo "\n";
 
     if (isset($message)) {
@@ -342,11 +350,7 @@ if (empty($is_info)) {
 }
 
 $db_collation = PMA_getDbCollation($db);
-if ($db == 'information_schema') {
-    $is_information_schema = true;
-} else {
-    $is_information_schema = false;
-}
+$is_information_schema = PMA_is_system_schema($db);
 
 if (!$is_information_schema) {
     if ($cfgRelation['commwork']) {
@@ -359,7 +363,12 @@ if (!$is_information_schema) {
     <?php echo PMA_generate_common_hidden_inputs($db); ?>
     <fieldset>
         <legend>
-        <?php echo PMA_getIcon('b_comment.png', __('Database comment: '), false, true); ?>
+        <?php
+        if ($cfg['PropertiesIconic']) {
+            echo '<img class="icon ic_b_comment" src="themes/dot.gif" alt="" />';
+        }
+        echo __('Database comment: ');
+        ?>
         </legend>
         <input type="text" name="comment" class="textfield" size="30"
             value="<?php
@@ -374,7 +383,7 @@ if (!$is_information_schema) {
     }
     ?>
     <div class="operations_half_width">
-    <?php require './libraries/display_create_table.lib.php'; ?>
+    <?php include './libraries/display_create_table.lib.php'; ?>
     </div>
     <?php
     /**
@@ -398,24 +407,12 @@ if ($db != 'mysql') {
         <legend>
     <?php
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_edit.png"'
-            .' alt="" width="16" height="16" />';
+        echo PMA_getImage('b_edit.png');
     }
     echo __('Rename database to') . ':';
     ?>
         </legend>
         <input id="new_db_name" type="text" name="newname" size="30" class="textfield" value="" />
-        <?php
-    echo '(' . __('Command') . ': ';
-    /**
-     * @todo (see explanations above in a previous todo)
-     */
-    //if (PMA_MYSQL_INT_VERSION >= XYYZZ) {
-    //    echo 'RENAME DATABASE';
-    //} else {
-        echo 'INSERT INTO ... SELECT';
-    //}
-    echo ')'; ?>
     </fieldset>
     <fieldset class="tblFooters">
         <input id="rename_db_input" type="submit" value="<?php echo __('Go'); ?>" />
@@ -428,14 +425,15 @@ if ($db != 'mysql') {
 // Drop link if allowed
 // Don't even try to drop information_schema. You won't be able to. Believe me. You won't.
 // Don't allow to easily drop mysql database, RFE #1327514.
-if (($is_superuser || $GLOBALS['cfg']['AllowUserDropDatabase']) && ! $db_is_information_schema && ($db != 'mysql')) {
+if (($is_superuser || $GLOBALS['cfg']['AllowUserDropDatabase'])
+        && !$db_is_information_schema
+        && (PMA_DRIZZLE || $db != 'mysql')) {
 ?>
 <div class="operations_half_width">
 <fieldset class="caution">
  <legend><?php
 if ($cfg['PropertiesIconic']) {
-    echo '<img class="icon" src="' . $pmaThemeImage . 'b_deltbl.png"'
-        .' alt="" width="16" height="16" />';
+    echo PMA_getImage('b_deltbl.png');
 }
 echo __('Remove database');
 ?></legend>
@@ -450,7 +448,7 @@ echo __('Remove database');
             'reload' => '1',
             'purge' => '1',
             'message_to_show' => sprintf(__('Database %s has been dropped.'), htmlspecialchars(PMA_backquote($db))),
-            'db' => NULL,
+            'db' => null,
         );
     ?>
         <li><a href="sql.php<?php echo PMA_generate_common_url($this_url_params); ?>" <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? 'id="drop_db_anchor"' : ''); ?>>
@@ -481,8 +479,7 @@ echo __('Remove database');
         <legend>
     <?php
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_edit.png"'
-            .' alt="" width="16" height="16" />';
+        echo PMA_getImage('b_edit.png');
     }
     echo __('Copy database to') . ':';
     $drop_clause = 'DROP TABLE / DROP VIEW';
@@ -546,8 +543,7 @@ echo __('Remove database');
        . '<fieldset>' . "\n"
        . '    <legend>';
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 's_asci.png"'
-            .' alt="" width="16" height="16" />';
+        echo PMA_getImage('s_asci.png');
     }
     echo '    <label for="select_db_collation">' . __('Collation') . ':</label>' . "\n"
        . '    </legend>' . "\n"
@@ -561,7 +557,7 @@ echo __('Remove database');
        . '</form></div>' . "\n";
 
     if ($num_tables > 0
-      && !$cfgRelation['allworks'] && $cfg['PmaNoRelation_DisableWarning'] == false) {
+      && ! $cfgRelation['allworks'] && $cfg['PmaNoRelation_DisableWarning'] == false) {
         $message = PMA_Message::notice(__('The phpMyAdmin configuration storage has been deactivated. To find out why click %shere%s.'));
         $message->addParam('<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?' . $url_query . '">', false);
         $message->addParam('</a>', false);
@@ -586,7 +582,7 @@ if ($cfgRelation['pdfwork'] && $num_tables > 0) { ?>
     $test_query = '
          SELECT *
            FROM ' . PMA_backquote($GLOBALS['cfgRelation']['db']) . '.' . PMA_backquote($cfgRelation['pdf_pages']) . '
-          WHERE db_name = \'' . PMA_sqlAddslashes($db) . '\'';
+          WHERE db_name = \'' . PMA_sqlAddSlashes($db) . '\'';
     $test_rs    = PMA_query_as_controluser($test_query, null, PMA_DBI_QUERY_STORE);
 
     /*
@@ -594,8 +590,7 @@ if ($cfgRelation['pdfwork'] && $num_tables > 0) { ?>
      */
     echo '<div class="operations_full_width"><fieldset><a href="schema_edit.php?' . $url_query . '">';
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_edit.png"'
-            .' alt="" width="16" height="16" />';
+        echo PMA_getImage('b_edit.png');
     }
     echo __('Edit or export relational schema') . '</a></fieldset></div>';
 } // end if
