@@ -3,9 +3,7 @@
 /**
  * Holds class PMA_Message
  *
- * @author Sebastian Mendel <info@sebastianmendel.de>
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -21,9 +19,6 @@
  *
  * // get special notice 'Some locale notice'
  * $message = PMA_Message::notice('strSomeLocaleNotice');
- *
- * // display raw warning message 'This is a warning!'
- * PMA_Message::rawWarning('This is a warning!')->display();
  * </code>
  *
  * more advanced usage example:
@@ -59,13 +54,12 @@
  * // strSomeLocaleMessage <sup>1</sup> strSomeMoreLocale<br />
  * // strSomeEvenMoreLocale - some final words
  * </code>
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 class PMA_Message
 {
     const SUCCESS = 1; // 0001
     const NOTICE  = 2; // 0010
-    const WARNING = 4; // 0100
     const ERROR   = 8; // 1000
 
     const SANITIZE_NONE   = 0;  // 0000 0000
@@ -81,7 +75,6 @@ class PMA_Message
     static public $level = array (
         PMA_Message::SUCCESS => 'success',
         PMA_Message::NOTICE  => 'notice',
-        PMA_Message::WARNING => 'warning',
         PMA_Message::ERROR   => 'error',
     );
 
@@ -144,17 +137,10 @@ class PMA_Message
     /**
      * Constructor
      *
-     * @uses    PMA_Message::setNumber()
-     * @uses    PMA_Message::setString()
-     * @uses    PMA_Message::setParams()
-     * @uses    PMA_Message::NOTICE
-     * @uses    PMA_Message::SANITIZE_NONE
-     * @uses    PMA_Message::SANITIZE_STRING
-     * @uses    PMA_Message::SANITIZE_PARAMS
-     * @param   string  $string
-     * @param   integer $number
-     * @param   array   $$params
-     * @param   boolean $sanitize
+     * @param string  $string
+     * @param integer $number
+     * @param array   $params
+     * @param integer $sanitize
      */
     public function __construct($string = '', $number = PMA_Message::NOTICE,
         $params = array(), $sanitize = PMA_Message::SANITIZE_NONE)
@@ -167,7 +153,6 @@ class PMA_Message
     /**
      * magic method: return string representation for this object
      *
-     * @uses    PMA_Message::getMessage()
      * @return string
      */
     public function __toString()
@@ -181,15 +166,13 @@ class PMA_Message
      * shorthand for getting a simple success message
      *
      * @static
-     * @uses    PMA_Message as returned object
-     * @uses    PMA_Message::SUCCESS
-     * @param   string $string a localized string e.g. 'strSuccess'
+     * @param string $string a localized string e.g. __('Your SQL query has been executed successfully')
      * @return  PMA_Message
      */
     static public function success($string = '')
     {
         if (empty($string)) {
-            $string = 'strSuccess';
+            $string = __('Your SQL query has been executed successfully');
         }
 
         return new PMA_Message($string, PMA_Message::SUCCESS);
@@ -201,45 +184,25 @@ class PMA_Message
      * shorthand for getting a simple error message
      *
      * @static
-     * @uses    PMA_Message as returned object
-     * @uses    PMA_Message::ERROR
-     * @param   string $string a localized string e.g. 'strError'
+     * @param string $string a localized string e.g. __('Error')
      * @return  PMA_Message
      */
     static public function error($string = '')
     {
         if (empty($string)) {
-            $string = 'strError';
+            $string = __('Error');
         }
 
         return new PMA_Message($string, PMA_Message::ERROR);
     }
 
-    /**
-     * get PMA_Message of type warning
-     *
-     * shorthand for getting a simple warning message
-     *
-     * @static
-     * @uses    PMA_Message as returned object
-     * @uses    PMA_Message::WARNING
-     * @param   string $string a localized string e.g. 'strSetupWarning'
-     * @return  PMA_Message
-     */
-    static public function warning($string)
-    {
-        return new PMA_Message($string, PMA_Message::WARNING);
-    }
-
     /**
      * get PMA_Message of type notice
      *
      * shorthand for getting a simple notice message
      *
      * @static
-     * @uses    PMA_Message as returned object
-     * @uses    PMA_Message::NOTICE
-     * @param   string  $string a localized string e.g. 'strRelationNotWorking'
+     * @param string  $string a localized string e.g. __('The additional features for working with linked tables have been deactivated. To find out why click %shere%s.')
      * @return  PMA_Message
      */
     static public function notice($string)
@@ -253,10 +216,8 @@ class PMA_Message
      * shorthand for getting a customized message
      *
      * @static
-     * @uses    PMA_Message as returned object
-     * @uses    PMA_Message::setMessage()
-     * @param   string    $message
-     * @param   integer   $type
+     * @param string    $message
+     * @param integer   $type
      * @return  PMA_Message
      */
     static public function raw($message, $type = PMA_Message::NOTICE)
@@ -266,15 +227,61 @@ class PMA_Message
         return $r;
     }
 
+    /**
+     * get PMA_Message for number of affected rows
+     *
+     * shorthand for getting a customized message
+     *
+     * @static
+     * @param integer   $rows Number of rows
+     * @return  PMA_Message
+     */
+    static public function affected_rows($rows)
+    {
+        $message = PMA_Message::success(_ngettext('%1$d row affected.', '%1$d rows affected.', $rows));
+        $message->addParam($rows);
+        return $message;
+    }
+
+    /**
+     * get PMA_Message for number of deleted rows
+     *
+     * shorthand for getting a customized message
+     *
+     * @static
+     * @param integer   $rows Number of rows
+     * @return  PMA_Message
+     */
+    static public function deleted_rows($rows)
+    {
+        $message = PMA_Message::success(_ngettext('%1$d row deleted.', '%1$d rows deleted.', $rows));
+        $message->addParam($rows);
+        return $message;
+    }
+
+    /**
+     * get PMA_Message for number of inserted rows
+     *
+     * shorthand for getting a customized message
+     *
+     * @static
+     * @param integer   $rows Number of rows
+     * @return  PMA_Message
+     */
+    static public function inserted_rows($rows)
+    {
+        $message = PMA_Message::success(_ngettext('%1$d row inserted.', '%1$d rows inserted.', $rows));
+        $message->addParam($rows);
+        return $message;
+    }
+
     /**
      * get PMA_Message of type error with custom content
      *
      * shorthand for getting a customized error message
      *
      * @static
-     * @uses    PMA_Message::raw()
-     * @uses    PMA_Message::ERROR
-     * @param   string  $message
+     * @param string  $message
      * @return  PMA_Message
      */
     static public function rawError($message)
@@ -282,31 +289,13 @@ class PMA_Message
         return PMA_Message::raw($message, PMA_Message::ERROR);
     }
 
-    /**
-     * get PMA_Message of type warning with custom content
-     *
-     * shorthand for getting a customized warning message
-     *
-     * @static
-     * @uses    PMA_Message::raw()
-     * @uses    PMA_Message::WARNING
-     * @param   string  $message
-     * @return  PMA_Message
-     */
-    static public function rawWarning($message)
-    {
-        return PMA_Message::raw($message, PMA_Message::WARNING);
-    }
-
     /**
      * get PMA_Message of type notice with custom content
      *
      * shorthand for getting a customized notice message
      *
      * @static
-     * @uses    PMA_Message::raw()
-     * @uses    PMA_Message::NOTICE
-     * @param   string  $message
+     * @param string  $message
      * @return  PMA_Message
      */
     static public function rawNotice($message)
@@ -320,9 +309,7 @@ class PMA_Message
      * shorthand for getting a customized success message
      *
      * @static
-     * @uses    PMA_Message::raw()
-     * @uses    PMA_Message::SUCCESS
-     * @param   string  $message
+     * @param string  $message
      * @return  PMA_Message
      */
     static public function rawSuccess($message)
@@ -334,10 +321,7 @@ class PMA_Message
      * returns whether this message is a success message or not
      * and optionaly makes this message a success message
      *
-     * @uses    PMA_Message::SUCCESS
-     * @uses    PMA_Message::setNumber()
-     * @uses    PMA_Message::getNumber()
-     * @param   boolean $set
+     * @param boolean $set
      * @return  boolean whether this is a success message or not
      */
     public function isSuccess($set = false)
@@ -353,10 +337,7 @@ class PMA_Message
      * returns whether this message is a notice message or not
      * and optionally makes this message a notice message
      *
-     * @uses    PMA_Message::NOTICE
-     * @uses    PMA_Message::setNumber()
-     * @uses    PMA_Message::getNumber()
-     * @param   boolean $set
+     * @param boolean $set
      * @return  boolean whether this is a notice message or not
      */
     public function isNotice($set = false)
@@ -368,33 +349,11 @@ class PMA_Message
         return $this->getNumber() === PMA_Message::NOTICE;
     }
 
-    /**
-     * returns whether this message is a warning message or not
-     * and optionally makes this message a warning message
-     *
-     * @uses    PMA_Message::WARNING
-     * @uses    PMA_Message::setNumber()
-     * @uses    PMA_Message::getNumber()
-     * @param   boolean $set
-     * @return  boolean whether this is a warning message or not
-     */
-    public function isWarning($set = false)
-    {
-        if ($set) {
-            $this->setNumber(PMA_Message::WARNING);
-        }
-
-        return $this->getNumber() === PMA_Message::WARNING;
-    }
-
     /**
      * returns whether this message is an error message or not
      * and optionally makes this message an error message
      *
-     * @uses    PMA_Message::ERROR
-     * @uses    PMA_Message::setNumber()
-     * @uses    PMA_Message::getNumber()
-     * @param   boolean $set
+     * @param boolean $set
      * @return  boolean whether this is an error message or not
      */
     public function isError($set = false)
@@ -409,10 +368,8 @@ class PMA_Message
     /**
      * set raw message (overrides string)
      *
-     * @uses    PMA_Message::$_message to set it
-     * @uses    PMA_Message::sanitize()
-     * @param   string  $message
-     * @param   boolean $sanitize whether to sanitize $message or not
+     * @param string  $message
+     * @param boolean $sanitize whether to sanitize $message or not
      */
     public function setMessage($message, $sanitize = false)
     {
@@ -425,10 +382,8 @@ class PMA_Message
     /**
      * set string (does not take effect if raw message is set)
      *
-     * @uses    PMA_Message::$_string to set it
-     * @uses    PMA_Message::sanitize()
-     * @param   string  $_string
-     * @param   boolean $sanitize whether to sanitize $string or not
+     * @param string  $_string
+     * @param boolean $sanitize whether to sanitize $string or not
      */
     public function setString($_string, $sanitize = true)
     {
@@ -441,8 +396,7 @@ class PMA_Message
     /**
      * set message type number
      *
-     * @uses    PMA_Message::$_number to set it
-     * @param   integer $number
+     * @param integer $number
      */
     public function setNumber($number)
     {
@@ -459,11 +413,8 @@ class PMA_Message
      * $message->addParam('<img src="img" />', false);
      * </code>
      *
-     * @uses    htmlspecialchars()
-     * @uses    PMA_Message::$_params to fill
-     * @uses    PMA_Message::notice()
-     * @param   mixed   $param
-     * @param   boolean $raw
+     * @param mixed   $param
+     * @param boolean $raw
      */
     public function addParam($param, $raw = true)
     {
@@ -479,10 +430,8 @@ class PMA_Message
     /**
      * add another string to be concatenated on displaying
      *
-     * @uses    PMA_Message::$_added_messages to fill
-     * @uses    PMA_Message::notice()
-     * @param   string  $string    to be added
-     * @param   string  $separator to use between this and previous string/message
+     * @param string  $string    to be added
+     * @param string  $separator to use between this and previous string/message
      */
     public function addString($string, $separator = ' ')
     {
@@ -493,9 +442,8 @@ class PMA_Message
     /**
      * add a bunch of messages at once
      *
-     * @uses    PMA_Message::addMessage()
-     * @param   array   $messages  to be added
-     * @param   string  $separator to use between this and previous string/message
+     * @param array   $messages  to be added
+     * @param string  $separator to use between this and previous string/message
      */
     public function addMessages($messages, $separator = ' ')
     {
@@ -507,10 +455,8 @@ class PMA_Message
     /**
      * add another raw message to be concatenated on displaying
      *
-     * @uses    PMA_Message::$_added_messages to fill
-     * @uses    PMA_Message::rawNotice()
-     * @param   mixed   $message   to be added
-     * @param   string  $separator to use between this and previous string/message
+     * @param mixed   $message   to be added
+     * @param string  $separator to use between this and previous string/message
      */
     public function addMessage($message, $separator = ' ')
     {
@@ -528,10 +474,8 @@ class PMA_Message
     /**
      * set all params at once, usually used in conjunction with string
      *
-     * @uses    PMA_Message::sanitize()
-     * @uses    PMA_Message::$_params to set
-     * @param   array   $params
-     * @param   boolean $sanitize
+     * @param array   $params
+     * @param boolean $sanitize
      */
     public function setParams($params, $sanitize = false)
     {
@@ -544,7 +488,6 @@ class PMA_Message
     /**
      * return all parameters
      *
-     * @uses    PMA_Message::$_params as return value
      * @return array
      */
     public function getParams()
@@ -555,7 +498,6 @@ class PMA_Message
     /**
      * return all added messages
      *
-     * @uses    PMA_Message::$_added_messages as return value
      * @return array
      */
     public function getAddedMessages()
@@ -567,11 +509,8 @@ class PMA_Message
      * Sanitizes $message
      *
      * @static
-     * @uses    is_array()
-     * @uses    htmlspecialchars()
-     * @uses    PMA_Message::sanitize() recursiv
-     * @param   mixed   the message(s)
-     * @return  mixed   the sanitized message(s)
+     * @param mixed  $message the message(s)
+     * @return  mixed  the sanitized message(s)
      * @access  public
      */
     static public function sanitize($message)
@@ -592,75 +531,18 @@ class PMA_Message
      * for formatting
      *
      * @static
-     * @uses    PREG_SET_ORDER
-     * @uses    in_array()
-     * @uses    preg_match_all()
-     * @uses    preg_match()
-     * @uses    preg_replace()
-     * @uses    substr()
-     * @uses    strtr()
-     * @param   string  $message the message
+     * @param string  $message the message
      * @return  string  the decoded message
      * @access  public
      */
     static public function decodeBB($message)
     {
-        $replace_pairs = array(
-            '[i]'       => '<em>',      // deprecated by em
-            '[/i]'      => '</em>',     // deprecated by em
-            '[em]'      => '<em>',
-            '[/em]'     => '</em>',
-            '[b]'       => '<strong>',  // deprecated by strong
-            '[/b]'      => '</strong>', // deprecated by strong
-            '[strong]'  => '<strong>',
-            '[/strong]' => '</strong>',
-            '[tt]'      => '<code>',    // deprecated by CODE or KBD
-            '[/tt]'     => '</code>',   // deprecated by CODE or KBD
-            '[code]'    => '<code>',
-            '[/code]'   => '</code>',
-            '[kbd]'     => '<kbd>',
-            '[/kbd]'    => '</kbd>',
-            '[br]'      => '<br />',
-            '[/a]'      => '</a>',
-            '[sup]'     => '<sup>',
-            '[/sup]'    => '</sup>',
-        );
-
-        $message = strtr($message, $replace_pairs);
-
-        $pattern = '/\[a@([^"@]*)@([^]"]*)\]/';
-
-        if (preg_match_all($pattern, $message, $founds, PREG_SET_ORDER)) {
-            $valid_links = array(
-                'http',  // default http:// links (and https://)
-                './Do',  // ./Documentation
-            );
-
-            foreach ($founds as $found) {
-                // only http... and ./Do... allowed
-                if (! in_array(substr($found[1], 0, 4), $valid_links)) {
-                    return $message;
-                }
-                // a-z and _ allowed in target
-                if (! empty($found[2]) && preg_match('/[^a-z_]+/i', $found[2])) {
-                    return $message;
-                }
-            }
-
-            $message = preg_replace($pattern, '<a href="\1" target="\2">', $message);
-        }
-
-        return $message;
+        return PMA_sanitize($message, false, true);
     }
 
     /**
      * wrapper for sprintf()
      *
-     * @uses    sprintf()
-     * @uses    func_get_args()
-     * @uses    is_array()
-     * @uses    array_unshift()
-     * @uses    call_user_func_array()
      * @return  string formatted
      */
     static public function format()
@@ -677,12 +559,6 @@ class PMA_Message
     /**
      * returns unique PMA_Message::$_hash, if not exists it will be created
      *
-     * @uses    PMA_Message::$_hash as return value and to set it if required
-     * @uses    PMA_Message::getNumber()
-     * @uses    PMA_Message::$_string
-     * @uses    PMA_Message::$_message
-     * @uses    md5()
-     * @param   string $file
      * @return  string PMA_Message::$_hash
      */
     public function getHash()
@@ -701,13 +577,6 @@ class PMA_Message
     /**
      * returns compiled message
      *
-     * @uses    PMA_Message::$_message as return value
-     * @uses    PMA_Message::getString()
-     * @uses    PMA_Message::getParams()
-     * @uses    PMA_Message::format()
-     * @uses    PMA_Message::decodeBB()
-     * @uses    PMA_Message::getAddedMessages()
-     * @uses    strlen()
      * @return  string complete message
      */
     public function getMessage()
@@ -741,7 +610,6 @@ class PMA_Message
     /**
      * returns PMA_Message::$_string
      *
-     * @uses    PMA_Message::$_string as return value
      * @return  string PMA_Message::$_string
      */
     public function getString()
@@ -752,7 +620,6 @@ class PMA_Message
     /**
      * returns PMA_Message::$_number
      *
-     * @uses    PMA_Message::$_number as return value
      * @return  integer PMA_Message::$_number
      */
     public function getNumber()
@@ -763,8 +630,6 @@ class PMA_Message
     /**
      * returns level of message
      *
-     * @uses    PMA_Message::$level
-     * @uses    PMA_Message::getNumber()
      * @return  string  level of message
      */
     public function getLevel()
@@ -775,9 +640,6 @@ class PMA_Message
     /**
      * Displays the message in HTML
      *
-     * @uses    PMA_Message::getLevel()
-     * @uses    PMA_Message::getMessage()
-     * @uses    PMA_Message::isDisplayed()
      */
     public function display()
     {
@@ -788,6 +650,7 @@ class PMA_Message
     /**
      * returns HTML code for displaying this message
      *
+     *
      * @return string whole message box
      */
     public function getDisplay()
@@ -799,8 +662,7 @@ class PMA_Message
     /**
      * sets and returns whether the message was displayed or not
      *
-     * @uses    PMA_Message::$_is_displayed to set it and/or return it
-     * @param   boolean $is_displayed
+     * @param boolean $is_displayed
      * @return  boolean PMA_Message::$_is_displayed
      */
     public function isDisplayed($is_displayed = false)
