@@ -3,15 +3,14 @@
 /**
  * Displays form for password change
  *
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
 /**
- * loic1: autocomplete feature of IE kills the "onchange" event handler and it
+ * autocomplete feature of IE kills the "onchange" event handler and it
  *        must be replaced by the "onpropertychange" one in this case
  */
 $chg_evt_handler = (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER >= 5)
@@ -20,36 +19,36 @@ $chg_evt_handler = (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER >= 5)
 
 // Displays the form
 ?>
-<form method="post" action="<?php echo $GLOBALS['PMA_PHP_SELF']; ?>" name="chgPassword" onsubmit="return checkPassword(this)">
+    <form method="post" id="change_password_form" action="<?php echo $GLOBALS['PMA_PHP_SELF']; ?>" name="chgPassword" <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? 'class="ajax" ' : ''); ?>>
     <?php   echo PMA_generate_common_hidden_inputs();
             if (strpos($GLOBALS['PMA_PHP_SELF'], 'server_privileges') !== false) {
                 echo '<input type="hidden" name="username" value="' . htmlspecialchars($username) . '" />' . "\n"
                    . '<input type="hidden" name="hostname" value="' . htmlspecialchars($hostname) . '" />' . "\n";
             }?>
     <fieldset id="fieldset_change_password">
-        <legend><?php echo $GLOBALS['strChangePassword']; ?></legend>
-        <table class="data">
-        <tr class="odd noclick">
+        <legend><?php echo __('Change password'); ?></legend>
+        <table class="data noclick">
+        <tr class="odd">
             <td colspan="2">
                 <input type="radio" name="nopass" value="1" id="nopass_1" onclick="pma_pw.value = ''; pma_pw2.value = ''; this.checked = true" />
-        <label for="nopass_1"><?php echo $GLOBALS['strNoPassword'] . "\n"; ?></label>
+        <label for="nopass_1"><?php echo __('No Password') . "\n"; ?></label>
             </td>
         </tr>
-        <tr class="even noclick">
+        <tr class="even">
             <td>
                 <input type="radio" name="nopass" value="0" id="nopass_0" onclick="document.getElementById('text_pma_pw').focus();" checked="checked " />
-        <label for="nopass_0"><?php echo $GLOBALS['strPassword']; ?>:&nbsp;</label>
+        <label for="nopass_0"><?php echo __('Password'); ?>:&nbsp;</label>
             </td>
             <td>
                 <input type="password" name="pma_pw" id="text_pma_pw" size="10" class="textfield" <?php echo $chg_evt_handler; ?>="nopass[1].checked = true" />
         &nbsp;&nbsp;
-        <?php echo $GLOBALS['strReType']; ?>:&nbsp;
+        <?php echo __('Re-type'); ?>:&nbsp;
                 <input type="password" name="pma_pw2" id="text_pma_pw2" size="10" class="textfield" <?php echo $chg_evt_handler; ?>="nopass[1].checked = true" />
             </td>
         </tr>
         <tr>
             <td>
-            <?php echo $strPasswordHashing; ?>:
+            <?php echo __('Password Hashing'); ?>:
         </td>
         <td>
             <input type="radio" name="pw_hash" id="radio_pw_hash_new" value="new" checked="checked" />
@@ -58,27 +57,18 @@ $chg_evt_handler = (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER >= 5)
             </label>
         </td>
         </tr>
-        <tr>
+        <tr id="tr_element_before_generate_password">
             <td>&nbsp;</td>
         <td>
             <input type="radio" name="pw_hash" id="radio_pw_hash_old" value="old" />
             <label for="radio_pw_hash_old">
-                <?php echo $strCompatibleHashing; ?>
+                <?php echo __('MySQL 4.0 compatible'); ?>
             </label>
         </td>
         </tr>
-        <tr>
-        <td>
-            <?php echo $strGeneratePassword; ?>
-        </td>
-        <td>
-            <input type="button" id="button_generate_password" value="<?php echo $strGenerate; ?>" onclick="suggestPassword(this.form)" />
-            <input type="text" name="generated_pw" id="generated_pw" />
-        </td>
-        </tr>
         </table>
     </fieldset>
     <fieldset id="fieldset_change_password_footer" class="tblFooters">
-            <input type="submit" name="change_pw" value="<?php echo($strGo); ?>" />
+            <input type="submit" name="change_pw" value="<?php echo(__('Go')); ?>" />
     </fieldset>
 </form>
