@@ -3,7 +3,7 @@
 /**
  * displays the pma logo, links and db and server selection in left frame
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -56,8 +56,7 @@ if ($GLOBALS['cfg']['LeftDisplayLogo']) {
     echo '<a href="main.php?' . $query_url . '"'
         .' title="' . __('Home') . '">'
         .($GLOBALS['cfg']['MainPageIconic']
-            ? '<img class="icon" src="' . $pmaThemeImage . 'b_home.png" width="16" '
-                .' height="16" alt="' . __('Home') . '" />'
+            ? PMA_getImage('b_home.png', __('Home'))
             : __('Home'))
         .'</a>' . "\n";
     // if we have chosen server
@@ -69,8 +68,7 @@ if ($GLOBALS['cfg']['LeftDisplayLogo']) {
                 .urlencode($PHP_AUTH_USER) . '" target="_parent"'
                 .' title="' . __('Log out') . '" >'
                 .($GLOBALS['cfg']['MainPageIconic']
-                    ? '<img class="icon" src="' . $pmaThemeImage . 's_loggoff.png" '
-                     .' width="16" height="16" alt="' . __('Log out') . '" />'
+                    ? PMA_getImage('s_loggoff.png', __('Log out'))
                     : __('Log out'))
                 .'</a>' . "\n";
         } // end if ($GLOBALS['cfg']['Server']['auth_type'] != 'config'
@@ -78,9 +76,7 @@ if ($GLOBALS['cfg']['LeftDisplayLogo']) {
         $anchor = 'querywindow.php?' . PMA_generate_common_url($db, $table);
 
         if ($GLOBALS['cfg']['MainPageIconic']) {
-            $query_frame_link_text =
-                '<img class="icon" src="' . $pmaThemeImage . 'b_selboard.png"'
-                .' width="16" height="16" alt="' . __('Query window') . '" />';
+            $query_frame_link_text = PMA_getImage('b_selboard.png', __('Query window'));
         } else {
             echo '<br />' . "\n";
             $query_frame_link_text = __('Query window');
@@ -95,8 +91,7 @@ if ($GLOBALS['cfg']['LeftDisplayLogo']) {
         .' title="' . __('phpMyAdmin documentation') . '" >';
 
     if ($GLOBALS['cfg']['MainPageIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_docs.png" width="16" height="16"'
-            .' alt="' . __('phpMyAdmin documentation') . '" />';
+        echo PMA_getImage('b_docs.png', __('phpMyAdmin documentation'));
     } else {
         echo '<br />' . __('phpMyAdmin documentation');
     }
@@ -119,9 +114,7 @@ if ($GLOBALS['cfg']['LeftDisplayLogo']) {
     echo '<a href="navigation.php?' . PMA_generate_common_url($params)
         . '" title="' . __('Reload navigation frame') . '" target="frame_navigation">';
     if ($GLOBALS['cfg']['MainPageIconic']) {
-        echo '<img class="icon" src="'. $GLOBALS['pmaThemeImage'] . 's_reload.png"'
-            . ' title="' . __('Reload navigation frame') . '"'
-            . ' alt="' . __('Reload navigation frame') . '" />';
+        echo PMA_getImage('s_reload.png', __('Reload navigation frame'));
     } else {
         echo '<br />' . __('Reload navigation frame');
     }
