@@ -2,8 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: parse_analyze.lib.php 11986 2008-11-24 11:05:40Z nijel $
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -16,7 +15,7 @@ $GLOBALS['unparsed_sql'] = $sql_query;
 $parsed_sql = PMA_SQP_parse($sql_query);
 $analyzed_sql = PMA_SQP_analyze($parsed_sql);
 
-// lem9: for bug 780516: now that we use case insensitive preg_match
+// for bug 780516: now that we use case insensitive preg_match
 // or flags from the analyser, do not put back the reformatted query
 // into $sql_query, to make this kind of query work without
 // capitalizing keywords:
@@ -53,7 +52,7 @@ if ($is_select) {
         $db = $prev_db;
     }
     // Nijel: don't change reload, if we already decided to reload in import
-    if (empty($reload)) {
+    if (empty($reload) && empty($GLOBALS['is_ajax_request'])) {
         $reload  = ($db == $prev_db) ? 0 : 1;
     }
 }
