@@ -3,40 +3,7 @@
 /**
  * display the binary logs and the content of the selected
  *
- * @uses    $cfg['MainPageIconic']
- * @uses    $cfg['NavigationBarIconic']
- * @uses    $cfg['MaxRows']
- * @uses    $cfg['LimitChars']
- * @uses    $pmaThemeImage
- * @uses    $GLOBALS['strBinaryLog']
- * @uses    $GLOBALS['strGo']
- * @uses    $GLOBALS['strTruncateQueries']
- * @uses    $GLOBALS['strShowFullQueries']
- * @uses    $GLOBALS['strBinLogName']
- * @uses    $GLOBALS['strBinLogPosition']
- * @uses    $GLOBALS['strBinLogEventType']
- * @uses    $GLOBALS['strBinLogServerId']
- * @uses    $GLOBALS['strBinLogOriginalPosition']
- * @uses    $GLOBALS['strBinLogInfo']
- * @uses    $GLOBALS['strFiles']
- * @uses    $GLOBALS['strPrevious']
- * @uses    $GLOBALS['strNext']
- * @uses    $binary_logs
- * @uses    PMA_generate_common_hidden_inputs()
- * @uses    PMA_generate_common_url()
- * @uses    PMA_formatByteDown()
- * @uses    PMA_DBI_fetch_assoc()
- * @uses    PMA_strlen()
- * @uses    PMA_substr()
- * @uses    $_REQUEST['pos']
- * @uses    $_REQUEST['log']
- * @uses    $_REQUEST['dontlimitchars']
- * @uses    count()
- * @uses    array_key_exists()
- * @uses    implode()
- * @uses    htmlspecialchars()
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -106,8 +73,8 @@ if (empty($_REQUEST['dontlimitchars'])) {
  * Displays the sub-page heading
  */
 echo '<h2>' . "\n"
-   . ($GLOBALS['cfg']['MainPageIconic'] ? '<img src="' . $pmaThemeImage . 's_process.png" width="16" height="16" border="0" hspace="2" align="middle" alt="" />' : '')
-   . '    ' . $GLOBALS['strBinaryLog'] . "\n"
+   . ($GLOBALS['cfg']['MainPageIconic'] ? PMA_getImage('s_tbl.png') : '')
+   . '    ' . __('Binary log') . "\n"
    . '</h2>' . "\n";
 
 /**
@@ -117,7 +84,7 @@ if (count($binary_logs) > 1) {
     echo '<form action="server_binlog.php" method="get">';
     echo PMA_generate_common_hidden_inputs($url_params);
     echo '<fieldset><legend>';
-    echo $GLOBALS['strSelectBinaryLog'];
+    echo __('Select binary log to view');
     echo '</legend><select name="log">';
     $full_size = 0;
     foreach ($binary_logs as $each_log) {
@@ -133,18 +100,18 @@ if (count($binary_logs) > 1) {
         echo '</option>';
     }
     echo '</select> ';
-    echo count($binary_logs) . ' ' . $GLOBALS['strFiles'] . ', ';
+    echo count($binary_logs) . ' ' . __('Files') . ', ';
     if ($full_size > 0) {
         echo implode(' ', PMA_formatByteDown($full_size));
     }
     echo '</fieldset>';
     echo '<fieldset class="tblFooters">';
-    echo '<input type="submit" value="' . $GLOBALS['strGo'] . '" />';
+    echo '<input type="submit" value="' . __('Go') . '" />';
     echo '</fieldset>';
     echo '</form>';
 }
 
-PMA_Message::success()->display();
+PMA_showMessage(PMA_Message::success());
 
 /**
  * Displays the page
@@ -165,9 +132,9 @@ if ($pos > 0) {
 
     echo '<a href="./server_binlog.php' . PMA_generate_common_url($this_url_params) . '"';
     if ($GLOBALS['cfg']['NavigationBarIconic']) {
-        echo ' title="' . $GLOBALS['strPrevious'] . '">';
+        echo ' title="' . _pgettext('Previous page', 'Previous') . '">';
     } else {
-        echo '>' . $GLOBALS['strPrevious'];
+        echo '>' . _pgettext('Previous page', 'Previous');
     } // end if... else...
     echo ' &lt; </a> - ';
 }
@@ -180,19 +147,17 @@ if ($dontlimitchars) {
     unset($this_url_params['dontlimitchars']);
     ?>
         <a href="./server_binlog.php<?php echo PMA_generate_common_url($this_url_params); ?>"
-            title="<?php $GLOBALS['strTruncateQueries']; ?>">
+            title="<?php __('Truncate Shown Queries'); ?>">
                 <img src="<?php echo $pmaThemeImage; ?>s_partialtext.png"
-                    width="50" height="20" border="0"
-                    alt="<?php echo $GLOBALS['strTruncateQueries']; ?>" /></a>
+                    alt="<?php echo __('Truncate Shown Queries'); ?>" /></a>
     <?php
 } else {
     $this_url_params['dontlimitchars'] = 1;
     ?>
         <a href="./server_binlog.php<?php echo PMA_generate_common_url($this_url_params); ?>"
-            title="<?php $GLOBALS['strShowFullQueries']; ?>">
+            title="<?php __('Show Full Queries'); ?>">
                 <img src="<?php echo $pmaThemeImage; ?>s_fulltext.png"
-                    width="50" height="20" border="0"
-                    alt="<?php echo $GLOBALS['strShowFullQueries']; ?>" /></a>
+                    alt="<?php echo __('Show Full Queries'); ?>" /></a>
     <?php
 }
 // we do not now how much rows are in the binlog
@@ -202,9 +167,9 @@ if ($num_rows >= $GLOBALS['cfg']['MaxRows']) {
     $this_url_params['pos'] = $pos + $GLOBALS['cfg']['MaxRows'];
     echo ' - <a href="./server_binlog.php' . PMA_generate_common_url($this_url_params) . '"';
     if ($GLOBALS['cfg']['NavigationBarIconic']) {
-        echo ' title="' . $GLOBALS['strNext'] . '">';
+        echo ' title="' . _pgettext('Next page', 'Next') . '">';
     } else {
-        echo '>' . $GLOBALS['strNext'];
+        echo '>' . _pgettext('Next page', 'Next');
     } // end if... else...
     echo ' &gt; </a>';
 }
@@ -212,12 +177,12 @@ if ($num_rows >= $GLOBALS['cfg']['MaxRows']) {
     </td>
 </tr>
 <tr>
-    <th><?php echo $GLOBALS['strBinLogName']; ?></th>
-    <th><?php echo $GLOBALS['strBinLogPosition']; ?></th>
-    <th><?php echo $GLOBALS['strBinLogEventType']; ?></th>
-    <th><?php echo $GLOBALS['strBinLogServerId']; ?></th>
-    <th><?php echo $GLOBALS['strBinLogOriginalPosition']; ?></th>
-    <th><?php echo $GLOBALS['strBinLogInfo']; ?></th>
+    <th><?php echo __('Log name'); ?></th>
+    <th><?php echo __('Position'); ?></th>
+    <th><?php echo __('Event type'); ?></th>
+    <th><?php echo __('Server ID'); ?></th>
+    <th><?php echo __('Original position'); ?></th>
+    <th><?php echo __('Information'); ?></th>
 </tr>
 </thead>
 <tbody>
@@ -228,7 +193,7 @@ while ($value = PMA_DBI_fetch_assoc($result)) {
         $value['Info'] = PMA_substr($value['Info'], 0, $GLOBALS['cfg']['LimitChars']) . '...';
     }
     ?>
-<tr class="<?php echo $odd_row ? 'odd' : 'even'; ?>">
+<tr class="noclick <?php echo $odd_row ? 'odd' : 'even'; ?>">
     <td>&nbsp;<?php echo $value['Log_name']; ?>&nbsp;</td>
     <td align="right">&nbsp;<?php echo $value['Pos']; ?>&nbsp;</td>
     <td>&nbsp;<?php echo $value['Event_type']; ?>&nbsp;</td>
@@ -248,6 +213,6 @@ while ($value = PMA_DBI_fetch_assoc($result)) {
 /**
  * Sends the footer
  */
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
 
 ?>
