@@ -1,12 +1,9 @@
 <?php
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Validation callback.
  *
- * @package    phpMyAdmin-setup
- * @author     Piotr Przybylski <piotrprz@gmail.com>
- * @copyright  Copyright (c) 2008, Piotr Przybylski <piotrprz@gmail.com>
- * @license    http://www.gnu.org/licenses/gpl.html GNU GPL 2.0
- * @version    $Id: validate.php 11983 2008-11-24 10:33:42Z nijel $
+ * @package PhpMyAdmin-setup
  */
 
 /**
@@ -15,17 +12,17 @@
 require './lib/common.inc.php';
 
 $validators = array();
-require './setup/lib/validate.lib.php';
+require './libraries/config/validate.lib.php';
 
 header('Content-type: application/json');
 
 $vids = explode(',', filter_input(INPUT_POST, 'id'));
 $values = json_decode(filter_input(INPUT_POST, 'values'));
 if (!($values instanceof stdClass)) {
-    die('Wrong data');
+    die(__('Wrong data'));
 }
 $values = (array)$values;
-$result = validate($vids, $values, true);
+$result = PMA_config_validate($vids, $values, true);
 if ($result === false) {
     $result = 'Wrong data or no validation for ' . $vids;
 }
