@@ -8,34 +8,7 @@
  *
  * @todo 'edit_next' tends to not work as expected if used ... at least there is no order by
  *       it needs the original query and the row number and than replace the LIMIT clause
- * @uses    PMA_checkParameters()
- * @uses    PMA_DBI_select_db()
- * @uses    PMA_DBI_query()
- * @uses    PMA_DBI_fetch_row()
- * @uses    PMA_DBI_get_fields_meta()
- * @uses    PMA_DBI_free_result()
- * @uses    PMA_DBI_try_query()
- * @uses    PMA_DBI_getError()
- * @uses    PMA_DBI_affected_rows()
- * @uses    PMA_DBI_insert_id()
- * @uses    PMA_backquote()
- * @uses    PMA_getUniqueCondition()
- * @uses    PMA_sqlAddslashes()
- * @uses    PMA_securePath()
- * @uses    PMA_sendHeaderLocation()
- * @uses    str_replace()
- * @uses    count()
- * @uses    file_exists()
- * @uses    strlen()
- * @uses    str_replace()
- * @uses    preg_replace()
- * @uses    is_array()
- * @uses    $GLOBALS['db']
- * @uses    $GLOBALS['table']
- * @uses    $GLOBALS['goto']
- * @uses    $GLOBALS['sql_query']
- * @uses    PMA_File::getRecentBLOBReference()
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -65,14 +38,19 @@ PMA_DBI_select_db($GLOBALS['db']);
  */
 $goto_include = false;
 
+$GLOBALS['js_include'][] = 'makegrid.js';
 // Needed for generation of Inline Edit anchors
 $GLOBALS['js_include'][] = 'sql.js';
+$GLOBALS['js_include'][] = 'indexes.js';
+$GLOBALS['js_include'][] = 'gis_data_editor.js';
+$GLOBALS['js_include'][] = 'codemirror/lib/codemirror.js';
+$GLOBALS['js_include'][] = 'codemirror/mode/mysql/mysql.js';
 
 if (isset($_REQUEST['insert_rows']) && is_numeric($_REQUEST['insert_rows']) && $_REQUEST['insert_rows'] != $cfg['InsertRows']) {
     $cfg['InsertRows'] = $_REQUEST['insert_rows'];
     $GLOBALS['js_include'][] = 'tbl_change.js';
-    require_once './libraries/header.inc.php';
-    require './tbl_change.php';
+    include_once './libraries/header.inc.php';
+    include './tbl_change.php';
     exit;
 }
 
@@ -156,18 +134,52 @@ if (isset($_REQUEST['where_clause'])) {
 $query = array();
 $value_sets = array();
 $func_no_param = array(
-    'NOW',
+    'CONNECTION_ID',
+    'CURRENT_USER',
     'CURDATE',
     'CURTIME',
+    'CURRENT_DATE',
+    'CURRENT_TIME',
+    'DATABASE',
+    'LAST_INSERT_ID',
+    'NOW',
+    'PI',
+    'RAND',
+    'SYSDATE',
+    'UNIX_TIMESTAMP',
+    'USER',
     'UTC_DATE',
     'UTC_TIME',
     'UTC_TIMESTAMP',
-    'UNIX_TIMESTAMP',
-    'RAND',
-    'USER',
-    'LAST_INSERT_ID',
     'UUID',
-    'CURRENT_USER',
+    'UUID_SHORT',
+    'VERSION',
+);
+$func_optional_param = array(
+    'RAND',
+    'UNIX_TIMESTAMP',
+);
+
+$gis_from_text_functions = array(
+    'GeomFromText',
+    'GeomCollFromText',
+    'LineFromText',
+    'MLineFromText',
+    'PointFromText',
+    'MPointFromText',
+    'PolyFromText',
+    'MPolyFromText',
+);
+
+$gis_from_wkb_functions = array(
+    'GeomFromWKB',
+    'GeomCollFromWKB',
+    'LineFromWKB',
+    'MLineFromWKB',
+    'PointFromWKB',
+    'MPointFromWKB',
+    'PolyFromWKB',
+    'MPolyFromWKB',
 );
 
 foreach ($loop_array as $rownumber => $where_clause) {
@@ -180,36 +192,36 @@ foreach ($loop_array as $rownumber => $where_clause) {
     $query_values = array();
 
     // Map multi-edit keys to single-level arrays, dependent on how we got the fields
-    $me_fields =
-        isset($_REQUEST['fields']['multi_edit'][$rownumber])
+    $me_fields
+        = isset($_REQUEST['fields']['multi_edit'][$rownumber])
         ? $_REQUEST['fields']['multi_edit'][$rownumber]
         : array();
-    $me_fields_name =
-        isset($_REQUEST['fields_name']['multi_edit'][$rownumber])
+    $me_fields_name
+        = isset($_REQUEST['fields_name']['multi_edit'][$rownumber])
         ? $_REQUEST['fields_name']['multi_edit'][$rownumber]
         : null;
-    $me_fields_prev =
-        isset($_REQUEST['fields_prev']['multi_edit'][$rownumber])
+    $me_fields_prev
+        = isset($_REQUEST['fields_prev']['multi_edit'][$rownumber])
         ? $_REQUEST['fields_prev']['multi_edit'][$rownumber]
         : null;
-    $me_funcs =
-        isset($_REQUEST['funcs']['multi_edit'][$rownumber])
+    $me_funcs
+        = isset($_REQUEST['funcs']['multi_edit'][$rownumber])
         ? $_REQUEST['funcs']['multi_edit'][$rownumber]
         : null;
-    $me_fields_type =
-        isset($_REQUEST['fields_type']['multi_edit'][$rownumber])
+    $me_fields_type
+        = isset($_REQUEST['fields_type']['multi_edit'][$rownumber])
         ? $_REQUEST['fields_type']['multi_edit'][$rownumber]
         : null;
-    $me_fields_null =
-        isset($_REQUEST['fields_null']['multi_edit'][$rownumber])
+    $me_fields_null
+        = isset($_REQUEST['fields_null']['multi_edit'][$rownumber])
         ? $_REQUEST['fields_null']['multi_edit'][$rownumber]
         : null;
-    $me_fields_null_prev =
-        isset($_REQUEST['fields_null_prev']['multi_edit'][$rownumber])
+    $me_fields_null_prev
+        = isset($_REQUEST['fields_null_prev']['multi_edit'][$rownumber])
         ? $_REQUEST['fields_null_prev']['multi_edit'][$rownumber]
         : null;
-    $me_auto_increment =
-        isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
+    $me_auto_increment
+        = isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
         ? $_REQUEST['auto_increment']['multi_edit'][$rownumber]
         : null;
 
@@ -218,16 +230,28 @@ foreach ($loop_array as $rownumber => $where_clause) {
     if ($is_insert && $using_key && isset($me_fields_type) && is_array($me_fields_type) && isset($where_clause)) {
         $prot_row = PMA_DBI_fetch_single_row('SELECT * FROM ' . PMA_backquote($table) . ' WHERE ' . $where_clause . ';');
     }
-    foreach ($me_fields as $key => $val) {
+
+    // When a select field is nullified, it's not present in $_REQUEST
+    // so initialize it; this way, the foreach($me_fields) will process it
+    foreach ($me_fields_name as $key => $val) {
+        if (! isset($me_fields[$key])) {
+            $me_fields[$key] = '';
+        }
+    }
+
+    // Iterate in the order of $me_fields_name, not $me_fields, to avoid problems
+    // when inserting multiple entries
+    foreach ($me_fields_name as $key => $field_name) {
+        $val = $me_fields[$key];
 
         // Note: $key is an md5 of the fieldname. The actual fieldname is available in $me_fields_name[$key]
 
-        require './libraries/tbl_replace_fields.inc.php';
+        include './libraries/tbl_replace_fields.inc.php';
 
         // for blobstreaming
         if ($blob_streaming_active) {
-            $remove_blob_repo = isset($_REQUEST['remove_blob_repo_' . $key]) ? $_REQUEST['remove_blob_repo_' . $key] : NULL;
-            $upload_blob_repo = isset($_REQUEST['upload_blob_repo_' . $key]) ? $_REQUEST['upload_blob_repo_' . $key] : NULL;
+            $remove_blob_repo = isset($_REQUEST['remove_blob_repo_' . $key]) ? $_REQUEST['remove_blob_repo_' . $key] : null;
+            $upload_blob_repo = isset($_REQUEST['upload_blob_repo_' . $key]) ? $_REQUEST['upload_blob_repo_' . $key] : null;
 
             // checks if an existing blob repository reference should be removed
             if (isset($remove_blob_repo) && ! isset($upload_blob_repo)) {
@@ -244,23 +268,31 @@ foreach ($loop_array as $rownumber => $where_clause) {
 
                 // if the most recent BLOB reference exists, set it as a field value
                 if (!is_null($bs_reference)) {
-                    $val = "'" . PMA_sqlAddslashes($bs_reference) . "'";
+                    $val = "'" . PMA_sqlAddSlashes($bs_reference) . "'";
                 }
             }
         }
 
         if (empty($me_funcs[$key])) {
             $cur_value = $val;
-        } elseif ('UNIX_TIMESTAMP' === $me_funcs[$key] && $val != "''") {
-            $cur_value = $me_funcs[$key] . '(' . $val . ')';
         } elseif ('UUID' === $me_funcs[$key]) {
             /* This way user will know what UUID new row has */
             $uuid = PMA_DBI_fetch_value('SELECT UUID()');
             $cur_value = "'" . $uuid . "'";
-        } elseif (in_array($me_funcs[$key], $func_no_param)) {
-            $cur_value = $me_funcs[$key] . '()';
-        } else {
+        } elseif ((in_array($me_funcs[$key], $gis_from_text_functions)
+            && substr($val, 0, 3) == "'''")
+            || in_array($me_funcs[$key], $gis_from_wkb_functions)
+        ) {
+            // Remove enclosing apostrophes
+            $val = substr($val, 1, strlen($val) - 2);
+            // Remove escaping apostrophes
+            $val = str_replace("''", "'", $val);
             $cur_value = $me_funcs[$key] . '(' . $val . ')';
+        } elseif (! in_array($me_funcs[$key], $func_no_param)
+                  || ($val != "''" && in_array($me_funcs[$key], $func_optional_param))) {
+            $cur_value = $me_funcs[$key] . '(' . $val . ')';
+        } else {
+            $cur_value = $me_funcs[$key] . '()';
         }
 
         //  i n s e r t
@@ -276,21 +308,21 @@ foreach ($loop_array as $rownumber => $where_clause) {
 
         //  u p d a t e
         } elseif (!empty($me_fields_null_prev[$key])
-         && !isset($me_fields_null[$key])) {
+         && ! isset($me_fields_null[$key])) {
             // field had the null checkbox before the update
             // field no longer has the null checkbox
             $query_values[] = PMA_backquote($me_fields_name[$key]) . ' = ' . $cur_value;
         } elseif (empty($me_funcs[$key])
          && isset($me_fields_prev[$key])
-         && ("'" . PMA_sqlAddslashes($me_fields_prev[$key]) . "'" == $val)) {
+         && ("'" . PMA_sqlAddSlashes($me_fields_prev[$key]) . "'" == $val)) {
             // No change for this column and no MySQL function is used -> next column
             continue;
         } elseif (! empty($val)) {
             // avoid setting a field to NULL when it's already NULL
             // (field had the null checkbox before the update
             //  field still has the null checkbox)
-            if (!(! empty($me_fields_null_prev[$key])
-             && isset($me_fields_null[$key]))) {
+            if (empty($me_fields_null_prev[$key])
+             || empty($me_fields_null[$key])) {
                  $query_values[] = PMA_backquote($me_fields_name[$key]) . ' = ' . $cur_value;
             }
         }
@@ -330,10 +362,10 @@ if ($is_insert && count($value_sets) > 0) {
     // Note: logic passes here for inline edit
     $message = PMA_Message::success(__('No change'));
     $active_page = $goto_include;
-    if(! $GLOBALS['is_ajax_request'] == true) {
-        require_once './libraries/header.inc.php';
+    if (! $GLOBALS['is_ajax_request'] == true) {
+        include_once './libraries/header.inc.php';
     }
-    require './' . PMA_securePath($goto_include);
+    include './' . PMA_securePath($goto_include);
     exit;
 }
 unset($me_fields, $is_insertignore);
@@ -368,7 +400,7 @@ foreach ($query as $single_query) {
     }
 
     if (! $result) {
-        $error_messages[] = PMA_DBI_getError();
+        $error_messages[] = PMA_Message::sanitize(PMA_DBI_getError());
     } else {
         // The next line contains a real assignment, it's not a typo
         if ($tmp = @PMA_DBI_affected_rows()) {
@@ -392,8 +424,10 @@ foreach ($query as $single_query) {
     } // end if
 
     foreach (PMA_DBI_get_warnings() as $warning) {
-        $warning_messages[] = $warning['Level'] . ': #' . $warning['Code']
-            . ' ' . $warning['Message'];
+        $warning_messages[]
+            = PMA_Message::sanitize(
+                $warning['Level'] . ': #' . $warning['Code'] . ' ' . $warning['Message']
+            );
     }
 
     unset($result);
@@ -409,10 +443,6 @@ if ($is_insert && count($value_sets) > 0) {
 $message->addMessages($last_messages, '<br />');
 
 if (! empty($warning_messages)) {
-    /**
-     * @todo use a <div class="error"> in PMA_showMessage() for this part of
-     * the message
-     */
     $message->addMessages($warning_messages, '<br />');
     $message->isError(true);
 }
@@ -422,9 +452,131 @@ if (! empty($error_messages)) {
 }
 unset($error_messages, $warning_messages, $total_affected_rows, $last_messages, $last_message);
 
-if($GLOBALS['is_ajax_request'] == true) {
+if ($GLOBALS['is_ajax_request'] == true) {
+    /**
+     * If we are in grid editing, we need to process the relational and
+     * transformed fields, if they were edited. After that, output the correct
+     * link/transformed value and exit
+     *
+     * Logic taken from libraries/display_tbl.lib.php
+     */
 
-    $extra_data['sql_query'] = PMA_showMessage(NULL, $GLOBALS['display_query']);
+    if (isset($_REQUEST['rel_fields_list']) && $_REQUEST['rel_fields_list'] != '') {
+        //handle relations work here for updated row.
+        include_once './libraries/relation.lib.php';
+
+        $map = PMA_getForeigners($db, $table, '', 'both');
+
+        $rel_fields = array();
+        parse_str($_REQUEST['rel_fields_list'], $rel_fields);
+
+        // loop for each relation cell
+        foreach ( $rel_fields as $cell_index => $curr_cell_rel_field) {
+
+            foreach ( $curr_cell_rel_field as $rel_field => $rel_field_value) {
+
+                $where_comparison = "='" . $rel_field_value . "'";
+                $display_field = PMA_getDisplayField($map[$rel_field]['foreign_db'], $map[$rel_field]['foreign_table']);
+
+                // Field to display from the foreign table?
+                if (isset($display_field) && strlen($display_field)) {
+                    $dispsql     = 'SELECT ' . PMA_backquote($display_field)
+                        . ' FROM ' . PMA_backquote($map[$rel_field]['foreign_db'])
+                        . '.' . PMA_backquote($map[$rel_field]['foreign_table'])
+                        . ' WHERE ' . PMA_backquote($map[$rel_field]['foreign_field'])
+                        . $where_comparison;
+                    $dispresult  = PMA_DBI_try_query($dispsql, null, PMA_DBI_QUERY_STORE);
+                    if ($dispresult && PMA_DBI_num_rows($dispresult) > 0) {
+                        list($dispval) = PMA_DBI_fetch_row($dispresult, 0);
+                    } else {
+                        //$dispval = __('Link not found');
+                    }
+                    @PMA_DBI_free_result($dispresult);
+                } else {
+                    $dispval     = '';
+                } // end if... else...
+
+                if ('K' == $_SESSION['tmp_user_values']['relational_display']) {
+                    // user chose "relational key" in the display options, so
+                    // the title contains the display field
+                    $title = (! empty($dispval))? ' title="' . htmlspecialchars($dispval) . '"' : '';
+                } else {
+                    $title = ' title="' . htmlspecialchars($rel_field_value) . '"';
+                }
+
+                $_url_params = array(
+                    'db'    => $map[$rel_field]['foreign_db'],
+                    'table' => $map[$rel_field]['foreign_table'],
+                    'pos'   => '0',
+                    'sql_query' => 'SELECT * FROM '
+                                        . PMA_backquote($map[$rel_field]['foreign_db']) . '.' . PMA_backquote($map[$rel_field]['foreign_table'])
+                                        . ' WHERE ' . PMA_backquote($map[$rel_field]['foreign_field'])
+                                        . $where_comparison
+                );
+                $output = '<a href="sql.php' . PMA_generate_common_url($_url_params) . '"' . $title . '>';
+
+                if ('D' == $_SESSION['tmp_user_values']['relational_display']) {
+                    // user chose "relational display field" in the
+                    // display options, so show display field in the cell
+                    $output .= (!empty($dispval)) ? htmlspecialchars($dispval) : '';
+                } else {
+                    // otherwise display data in the cell
+                    $output .= htmlspecialchars($rel_field_value);
+                }
+                $output .= '</a>';
+                $extra_data['relations'][$cell_index] = $output;
+            }
+        }   // end of loop for each relation cell
+    }
+
+    if (isset($_REQUEST['do_transformations']) && $_REQUEST['do_transformations'] == true ) {
+        include_once './libraries/transformations.lib.php';
+        //if some posted fields need to be transformed, generate them here.
+        $mime_map = PMA_getMIME($db, $table);
+
+        if ($mime_map === false) {
+            $mime_map = array();
+        }
+
+        $edited_values = array();
+        parse_str($_REQUEST['transform_fields_list'], $edited_values);
+
+        foreach ($mime_map as $transformation) {
+            $include_file = PMA_securePath($transformation['transformation']);
+            $column_name = $transformation['column_name'];
+
+            foreach ($edited_values as $cell_index => $curr_cell_edited_values) {
+                if (isset($curr_cell_edited_values[$column_name])) {
+                    $column_data = $curr_cell_edited_values[$column_name];
+
+                    $_url_params = array(
+                        'db'            => $db,
+                        'table'         => $table,
+                        'where_clause'  => $_REQUEST['where_clause'],
+                        'transform_key' => $column_name,
+                    );
+
+                    if (file_exists('./libraries/transformations/' . $include_file)) {
+                        $transformfunction_name = str_replace('.inc.php', '', $transformation['transformation']);
+
+                        include_once './libraries/transformations/' . $include_file;
+
+                        if (function_exists('PMA_transformation_' . $transformfunction_name)) {
+                            $transform_function = 'PMA_transformation_' . $transformfunction_name;
+                            $transform_options  = PMA_transformation_getOptions((isset($transformation['transformation_options']) ? $transformation['transformation_options'] : ''));
+                            $transform_options['wrapper_link'] = PMA_generate_common_url($_url_params);
+                        }
+                    }
+
+                    $extra_data['transformations'][$cell_index] = $transform_function($column_data, $transform_options);
+                }
+            }   // end of loop for each transformation cell
+        }   // end of loop for each $mime_map
+    }
+
+    /**Get the total row count of the table*/
+    $extra_data['row_count'] = PMA_Table::countRecords($_REQUEST['db'], $_REQUEST['table']);
+    $extra_data['sql_query'] = PMA_showMessage($message, $GLOBALS['display_query']);
     PMA_ajaxResponse($message, $message->isSuccess(), $extra_data);
 }
 
@@ -437,7 +589,7 @@ if (isset($return_to_sql_query)) {
 
 $GLOBALS['js_include'][] = 'tbl_change.js';
 // in case we call sql.php which needs those:
-$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.16.custom.js';
 
 $active_page = $goto_include;
 
